summaryrefslogtreecommitdiff
path: root/lib/jabber.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@status.net>2009-08-27 11:16:45 -0700
committerEvan Prodromou <evan@status.net>2009-08-27 11:16:45 -0700
commit5d09b6b3f0595540c66b703ae085f0af904fe30f (patch)
tree59269a4dacf90bbab9f0ff63afff4bf1781a1240 /lib/jabber.php
parentf1fda6c0503e32edfc99b297f4bf2cb07e629d9e (diff)
parent82b0927f5838f3c12816e03712df9460a9f77b72 (diff)
Merge branch '0.8.x' into 0.9.x
Conflicts: EVENTS.txt actions/finishremotesubscribe.php actions/postnotice.php actions/public.php actions/remotesubscribe.php actions/showstream.php actions/updateprofile.php actions/userauthorization.php classes/laconica.ini lib/common.php lib/oauthstore.php lib/omb.php
Diffstat (limited to 'lib/jabber.php')
-rw-r--r--lib/jabber.php16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/jabber.php b/lib/jabber.php
index e15076160..3dcdce5db 100644
--- a/lib/jabber.php
+++ b/lib/jabber.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* utility functions for Jabber/GTalk/XMPP messages
*
@@ -20,14 +20,14 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Network
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @copyright 2008 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @copyright 2008 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -67,7 +67,7 @@ function jabber_normalize_jid($jid)
}
/**
* the JID of the Jabber daemon for this Laconica instance
*
* @return string JID of the Jabber daemon
*/
@@ -309,7 +309,7 @@ function jabber_special_presence($type, $to=null, $show=null, $status=null)
* who have Jabber addresses, and have Jabber notification enabled, and
* have this subscription enabled for Jabber. It also sends the notice to
* all recipients of @-replies who have Jabber addresses and Jabber notification
* enabled. This is really the heart of Jabber distribution in Laconica.
*
* @param Notice $notice The notice to broadcast
*
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* utility functions for Jabber/GTalk/XMPP messages
@@ -67,7 +67,7 @@ function jabber_normalize_jid($jid)
}
/**
- * the JID of the Jabber daemon for this Laconica instance
+ * the JID of the Jabber daemon for this StatusNet instance
*
* @return string JID of the Jabber daemon
@@ -309,7 +309,7 @@ function jabber_special_presence($type, $to=null, $show=null, $status=null)
* have this subscription enabled for Jabber. It also sends the notice to
* all recipients of @-replies who have Jabber addresses and Jabber notification
- * enabled. This is really the heart of Jabber distribution in Laconica.
+ * enabled. This is really the heart of Jabber distribution in StatusNet.
*
* @param Notice $notice The notice to broadcast